@@ -151,10 +151,10 @@ H2cal <- function(data
     year.n = 1
     env.name = NULL
     year.name = NULL
-    fixed.model = "0 + (1|bloque) + geno"
+    fixed.model = "1 + (1|bloque) + geno"
     random.model = "1 + (1|bloque) + (1|geno)"
     summary = TRUE
-    emmeans = TRUE
+    emmeans = FALSE
     weights = NULL
     plot_diag = TRUE
     outliers.rm = TRUE
@@ -198,11 +198,11 @@ H2cal <- function(data
 
 # fit models --------------------------------------------------------------
   
-  # fixed genotype effect
+  #> fixed genotype effect
   f.md <- as.formula(paste(trait, paste(fixed.model, collapse = " + "), sep = " ~ "))
   g.fix <- eval(bquote(lme4::lmer(.(f.md), weights = weights, data = dt.fm)))
   
-  # random genotype effect
+  #> random genotype effect
   r.md <- as.formula(paste(trait, paste(random.model, collapse = " + "), sep = " ~ "))
   g.ran <- eval(bquote(lme4::lmer(.(r.md), weights = weights, data = dt.rm)))
 
@@ -214,7 +214,7 @@ H2cal <- function(data
     
   }
 
-  # Plot models -------------------------------------------------------------
+# Plot models -------------------------------------------------------------
 
   if (plot_diag == TRUE) {
 
@@ -233,17 +233,16 @@ H2cal <- function(data
     par(mfrow=c(1,1))
 
   }
-
-# -------------------------------------------------------------------------
-
-### handle model estimates
-
+  
+  
+# handle model estimates --------------------------------------------------
+  
 # number of genotypes
 
   gen.n <- g.ran %>%
     summary() %>%
     purrr::pluck("ngrps") %>%
-    .[gen.name]
+    .[{{gen.name}}]
 
 # genotypic variance component
 
@@ -365,9 +364,9 @@ H2cal <- function(data
     dplyr::filter(grp == "Residual") %>%
     dplyr::pull(vcov)
   
-
-## Best Linear Unbiased Estimators (BLUE) :: fixed model
-    
+  
+# Best Linear Unbiased Estimators (BLUE) :: fixed model -------------------
+  
     if(emmeans == TRUE){
       
       BLUE <- g.fix %>%
@@ -378,7 +377,8 @@ H2cal <- function(data
         tibble::as_tibble() %>%
         dplyr::rename(!!trait := 'emmean') 
       
-      # mean variance of a difference between genotypes (BLUEs)
+      
+# mean variance of a difference between genotypes (BLUEs) -----------------
       
       vdBLUE.avg <- BLUE %>%
         purrr::pluck("contrasts") %>%
@@ -389,40 +389,32 @@ H2cal <- function(data
       
     } else if (emmeans == FALSE) {
       
-      count <- vcov(g.fix) %>%
-        purrr::pluck("Dimnames") %>%
-        purrr::pluck(1) %>%
-        stringr::str_detect(gen.name) %>%
-        summary(.) %>%
-        purrr::pluck("FALSE") %>% 
-        as.numeric()
-      
-      if(length(count) == 0) { count <- 0 }
-  
       BLUEs <- g.fix %>%
         lme4::fixef() %>%
         data.frame() %>% 
         rownames_to_column({{gen.name}}) %>% 
         dplyr::rename(!!trait := .) %>% 
-        mutate(across({{gen.name}}, ~stringr::str_replace(., gen.name, ""))) %>% 
         mutate(across({{trait}}, as.numeric)) %>% 
         mutate(smith.w = diag(solve(vcov(g.fix)))) %>% 
-        dplyr::slice((count+1):NROW(.))  
+        #>
+        dplyr::filter(grepl({{gen.name}}, .data[[gen.name]])) %>% 
+        mutate(across({{gen.name}}, ~stringr::str_replace(., gen.name, "")))
       
       vdBLUE.avg <- g.fix %>%
         vcov(.) %>%
         base::as.matrix(.) %>%
         diag(.) %>%
         enframe() %>%
-        dplyr::slice((count+1):NROW(.)) %>% 
+        #>
+        dplyr::filter(grepl({{gen.name}}, .data$name)) %>% 
+        ##>
         select(!.data$name) %>% 
         deframe() %>% 
         mean()
       
     }
-
-
-# Best Linear Unbiased Predictors (BLUP) - random model -------------------
+  
+# Best Linear Unbiased Predictors (BLUP) :: random model -------------------
 
       BLUPs <- g.ran %>%
         stats::coef() %>%
@@ -435,14 +427,14 @@ H2cal <- function(data
         {if (!is.null(trial)) select(.data = ., trial, everything()) else .}
       
 # mean variance of a difference between genotypes (BLUPs) -----------------
-
+  
       vdBLUP.avg <- g.ran %>%
         lme4::ranef(condVar = TRUE) %>%
         purrr::pluck(gen.name) %>%
         attr("postVar") %>%
         purrr::as_vector(.) %>%
         mean(.)*2
-
+  
 # Summary table of adjusted means (BLUEs) ---------------------------------
 
     smd <- BLUEs %>%
